==> naive-ui-2.21.2.tgz: package/es/carousel/src/styles/index.cssr.js <==
import { c, cB, cE, cM } from '../../../_utils/cssr'; // vars:
// --bezier
// --dot-color
// --dot-color-active
// --dot-size
// --arrow-color

export default cB('carousel', `
 overflow: hidden;
 position: relative;
`, [cE('slides', `
 transition: transform .3s var(--bezier);
 display: flex;
 `, [c('> div', `
 overflow: hidden;
 `, [c('> img', `
 display: block;
 `)])]), cE('dots', `
 position: absolute;
 display: flex;
 flex-wrap: nowrap;
 `), cE('dot', `
 height: var(--dot-size);
 width: var(--dot-size);
 background-color: var(--dot-color);
 border-radius: 50%;
 cursor: pointer;
 transition:
 box-shadow .3s var(--bezier),
 background-color .3s var(--bezier);
 outline: none;
 `, [c('&:focus', `
 background-color: var(--dot-color-active);
 `), cM('active', `
 background-color: var(--dot-color-active);
 `), c('&:last-child', `
 margin-right: 0;
 `)]), cE('arrow', `
 position: absolute;
 transition: transform .3s var(--bezier);
 transform: scale(1);
 cursor: pointer;
 height: 48px;
 width: 48px;
 display: flex;
 align-items: center;
 justify-content: center;
 color: var(--arrow-color);
 `, [cM('right', `
 transform: translateY(-50%);
 top: 50%;
 right: 0;
 `, [c('&:hover', {
  transform: 'translateY(-50%) scale(1.1)'
}), c('&:active', {
  transform: 'translateY(-50%) scale(1)'
})]), cM('left', `
 transform: translateY(-50%);
 top: 50%;
 left: 0;
 `, [c('&:hover', {
  transform: 'translateY(-50%) scale(1.1)'
}), c('&:active', {
  transform: 'translateY(-50%) scale(1)'
})]), cM('top', `
 transform: translateX(-50%) rotate(90deg);
 top: 0;
 left: 50%;
 `, [c('&:hover', {
  transform: 'translateX(-50%) scale(1.1) rotate(90deg)'
}), c('&:active', {
  transform: 'translateX(-50%) scale(1) rotate(90deg)'
})]), cM('bottom', `
 transform: translateX(-50%) rotate(90deg);
 bottom: 0;
 left: 50%;
 `, [c('&:hover', {
  transform: 'translateX(-50%) scale(1.1) rotate(90deg)'
}), c('&:active', {
  transform: 'translateX(-50%) scale(1) rotate(90deg)'
})]), c('svg', {
  height: '100%',
  width: '100%'
})]), cM('left', [cE('slides', `
 flex-direction: column;
 `), cE('dots', `
 transform: translateY(-50%);
 top: 50%;
 left: 16px;
 flex-direction: column;
 `), cE('dot', `
 margin-bottom: 12px;
 `)]), cM('right', [cE('slides', `
 flex-direction: column;
 `), cE('dots', `
 transform: translateY(-50%);
 top: 50%;
 right: 16px;
 flex-direction: column;
 `), cE('dot', `
 margin-bottom: 12px;
 `)]), cM('top', [cE('dots', `
 transform: translateX(-50%);
 top: 16px;
 left: 50%;
 `), cE('dot', `
 margin-right: 12px;
 `)]), cM('bottom', [cE('dots', `
 transform: translateX(-50%);
 bottom: 16px;
 left: 50%;
 `), cE('dot', `
 margin-right: 12px;
 `)])]);

==> naive-ui-2.23.2.tgz: package/es/carousel/src/styles/index.cssr.js <==
import { c, cB, cE, cM } from '../../../_utils/cssr'; // vars:
// --bezier
// --dot-color
// --dot-color-active
// --dot-size
// --arrow-color

export default cB('carousel', `
 overflow: hidden;
 position: relative;
`, [cE('slides', `
 transition: transform .3s var(--n-bezier);
 display: flex;
 `, [c('> div', `
 overflow: hidden;
 `, [c('> img', `
 display: block;
 `)])]), cE('dots', `
 position: absolute;
 display: flex;
 flex-wrap: nowrap;
 `), cE('dot', `
 height: var(--n-dot-size);
 width: var(--n-dot-size);
 background-color: var(--n-dot-color);
 border-radius: 50%;
 cursor: pointer;
 transition:
 box-shadow .3s var(--n-bezier),
 background-color .3s var(--n-bezier);
 outline: none;
 `, [c('&:focus', `
 background-color: var(--n-dot-color-active);
 `), cM('active', `
 background-color: var(--n-dot-color-active);
 `), c('&:last-child', `
 margin-right: 0;
 `)]), cE('arrow', `
 position: absolute;
 transition: transform .3s var(--n-bezier);
 transform: scale(1);
 cursor: pointer;
 height: 48px;
 width: 48px;
 display: flex;
 align-items: center;
 justify-content: center;
 color: var(--n-arrow-color);
 `, [cM('right', `
 transform: translateY(-50%);
 top: 50%;
 right: 0;
 `, [c('&:hover', {
  transform: 'translateY(-50%) scale(1.1)'
}), c('&:active', {
  transform: 'translateY(-50%) scale(1)'
})]), cM('left', `
 transform: translateY(-50%);
 top: 50%;
 left: 0;
 `, [c('&:hover', {
  transform: 'translateY(-50%) scale(1.1)'
}), c('&:active', {
  transform: 'translateY(-50%) scale(1)'
})]), cM('top', `
 transform: translateX(-50%) rotate(90deg);
 top: 0;
 left: 50%;
 `, [c('&:hover', {
  transform: 'translateX(-50%) scale(1.1) rotate(90deg)'
}), c('&:active', {
  transform: 'translateX(-50%) scale(1) rotate(90deg)'
})]), cM('bottom', `
 transform: translateX(-50%) rotate(90deg);
 bottom: 0;
 left: 50%;
 `, [c('&:hover', {
  transform: 'translateX(-50%) scale(1.1) rotate(90deg)'
}), c('&:active', {
  transform: 'translateX(-50%) scale(1) rotate(90deg)'
})]), c('svg', {
  height: '100%',
  width: '100%'
})]), cM('left', [cE('slides', `
 flex-direction: column;
 `), cE('dots', `
 transform: translateY(-50%);
 top: 50%;
 left: 16px;
 flex-direction: column;
 `), cE('dot', `
 margin-bottom: 12px;
 `)]), cM('right', [cE('slides', `
 flex-direction: column;
 `), cE('dots', `
 transform: translateY(-50%);
 top: 50%;
 right: 16px;
 flex-direction: column;
 `), cE('dot', `
 margin-bottom: 12px;
 `)]), cM('top', [cE('dots', `
 transform: translateX(-50%);
 top: 16px;
 left: 50%;
 `), cE('dot', `
 margin-right: 12px;
 `)]), cM('bottom', [cE('dots', `
 transform: translateX(-50%);
 bottom: 16px;
 left: 50%;
 `), cE('dot', `
 margin-right: 12px;
 `)])]);
